import Category from './modals/Category';
import CgftEvent from './modals/CgftEvent';
import DataActivity from './modals/DataActivity';
import DataBase from './modals/DataBase';
import DataGovernance from './modals/DataGovernance';
import DistrictIndex from './modals/DistrictIndex';
import EventDetail from './modals/EventDetail';
import KeyArea from './modals/KeyArea';
import KeyAreaDetail from './modals/KeyAreaDetail';
import SignModel from './modals/SignModel';
import { ModalMapping } from './type';

export type ModalKey = keyof typeof Registry.RegistryList;

/** @see ModalMapping 弹窗注册在这里 */
export default class Registry {
  static readonly RegistryList = {
    /**
     * 行业指数弹窗
     * @module DistrictIndex
     * @see DistrictIndex.RightBox
     */
    districtIndex: {
      defaultConfig: {
        w: 2756,
        h: 846,
        title: '行业指数',
      },
      defaultProps: {},
      modal: DistrictIndex,
    },
    /**
     * 体征模型
     * @module overview
     * @see NewHome - > NewLeftSidebar -> CityRealTimeCQI
     */
    SignModel: {
      defaultConfig: {
        w: 1470,
        h: 846,
        title: '体征模型',
      },
      defaultProps: {},
      modal: SignModel,
    },
    /**
     * 诚管24高速通道
     * @module overview
     * @see
     */
    CgftEvent: {
      defaultConfig: {
        w: 1470,
        h: 846,
      },
      defaultProps: {
        singleType: '1',
      },
      modal: CgftEvent,
    },

    /**
     * EventDetail
     * @module Event
     * @see Event -> EventDetail
     */
    EventDetail: {
      defaultConfig: {
        // w: 1465,
        h: 950,
        title: '事件详情',
      },
      defaultProps: {},
      modal: EventDetail,
    },

    /**
     * 体征模型
     * @module overview
     * @see NewHome - > NewLeftSidebar -> CityRealTimeCQI
     */
    Category: {
      defaultConfig: {
        w: 1470,
        h: 846,
      },
      defaultProps: {},
      modal: Category,
    },

    keyArea: {
      defaultConfig: {
        w: 2771,
        h: 846,
        title: '重点区域',
        keepalive: true,
      },
      defaultProps: {},
      modal: KeyArea,
    },

    KeyAreaDetail: {
      defaultConfig: {
        w: 2771,
        h: 846,
        title: '重点区域详情',
      },
      defaultProps: {},
      modal: KeyAreaDetail,
    },
    DataBase: {
      defaultConfig: {
        w: 2343,
        h: 846,
        title: '数据仓库',
      },
      defaultProps: {},
      modal: DataBase,
    },
    DataActivity: {
      defaultConfig: {
        w: 1616,
        h: 935,
        title: '城市管理数据标签体系',
      },
      defaultProps: {},
      modal: DataActivity,
    },
    DataGovernance: {
      defaultConfig: {
        w: 1424,
        h: 846,
        title: '城管数据治理概况',
      },
      defaultProps: {},
      modal: DataGovernance,
    },
  };

  static get(modalKey: ModalKey) {
    return Registry.RegistryList[modalKey];
  }
}
